@@ -11,6 +11,8 @@ from pandas import (
     Series,
     to_datetime
 )
+from pandas.core.generic import NDFrame
+
 import numpy as np
 
 from .directive import parse
@@ -134,11 +136,22 @@ class StockDataFrame(DataFrame):
 
         return result
 
-    def _direct_get_column(self, key: str) -> Series:
-        """Gets the column directly from dataframe by key
+    def get_column(self, key: str) -> Series:
+        """Gets the column directly from dataframe by key.
+
+        This method applies column name aliases before getting the value.
         """
 
-        return self._get_item_cache(key)
+        origin_key = key
+
+        if key in self._stock_aliases_map:
+            # Map alias, if the key is an alias
+            key = self._stock_aliases_map[key]
+
+        try:
+            return self._get_item_cache(key)
+        except KeyError:
+            raise KeyError(f'column "{origin_key}" not found')
 
     def exec(
         self,
@@ -285,18 +298,17 @@ class StockDataFrame(DataFrame):
     ) -> None:
         """Set a new column and avoid SettingWithCopyWarning by using
         pandas internal APIs
-        """
 
-        value = np.atleast_2d(value)
+        see: https://github.com/pandas-dev/pandas/blob/v1.1.0/pandas/core/frame.py#L3114
+        """  # noqa: E501
 
-        self._data.set(name, value)
-        self._clear_item_cache()
+        NDFrame._set_item(self, name, value)
 
     def _fulfill_series(self, column_name: str) -> np.ndarray:
         column_info = self._stock_columns_info_map.get(column_name)
         size = len(self)
 
-        array = self._direct_get_column(column_name).to_numpy()
+        array = self.get_column(column_name).to_numpy()
 
         if size == column_info.size:
             # Already fulfilled
