@@ -1,8 +1,9 @@
 from .parser import Parser
 from .factory import create_by_node
+from .types import Directive
 
 
-def parse(directive_str: str, cache):
+def parse(directive_str: str, cache) -> Directive:
     directive_str = directive_str.strip()
 
     cached = cache.get(directive_str)
@@ -15,4 +16,4 @@ def parse(directive_str: str, cache):
 
     cache.set(directive_str, directive)
 
-    return directive
+    return directive  # type: ignore
